==> runawfe-free-server-4.3.0.tar.gz: runawfe-free-server-4.3.0/wfe-web/src/main/java/ru/runa/af/web/MessagesExecutor.java <==
package ru.runa.af.web;

import ru.runa.common.web.StrutsMessage;

public final class MessagesExecutor {

    public static final StrutsMessage UNAUTHORIZED_EXECUTOR_NAME = new StrutsMessage("label.executor.unauthorized");

    public static final StrutsMessage TITLE_EXECUTORS = new StrutsMessage("title.executors");
    public static final StrutsMessage CREATE_ACTOR = new StrutsMessage("button.create_actor");
    public static final StrutsMessage CREATE_GROUP = new StrutsMessage("button.create_group");

    public static final StrutsMessage EXECUTOR_NAME = new StrutsMessage("label.executor_name");
    public static final StrutsMessage EXECUTOR_DESCRIPTION = new StrutsMessage("label.executor_description");
    public static final StrutsMessage ACTOR_FULL_NAME = new StrutsMessage("label.actor_fullname");
    public static final StrutsMessage ACTOR_CODE = new StrutsMessage("label.actor_code");
    public static final StrutsMessage ACTOR_IS_ACTIVE = new StrutsMessage("label.actor_is_active");
    public static final StrutsMessage ACTOR_EMAIL = new StrutsMessage("label.actor_email");
    public static final StrutsMessage ACTOR_PHONE = new StrutsMessage("label.actor_phone");
    public static final StrutsMessage ACTOR_TITLE = new StrutsMessage("label.actor_title");
    public static final StrutsMessage ACTOR_DEPARTMENT = new StrutsMessage("label.actor_department");
    public static final StrutsMessage GROUP_AD = new StrutsMessage("label.group_ad");

    public static final StrutsMessage TITLE_SUBSTITUTION_CRITERIA = new StrutsMessage("title.substitution_criteria");
    public static final StrutsMessage TITLE_ADD_EXECUTORS_TO_GROUP = new StrutsMessage("title.add_executors_to_group");
    public static final StrutsMessage TITLE_ADD_EXECUTOR_TO_GROUP = new StrutsMessage("title.add_executor_to_groups");
    public static final StrutsMessage TITLE_EXECUTOR_DETAILS = new StrutsMessage("title.executor_details");
    public static final StrutsMessage TITLE_EXECUTOR_GROUPS = new StrutsMessage("title.executor_groups");
    public static final StrutsMessage TITLE_GROUP_MEMBERS = new StrutsMessage("title.group_members");
    public static final StrutsMessage TITLE_ACTOR_PASSWORD = new StrutsMessage("title.actor_password");
    public static final StrutsMessage TITLE_ACTOR_STATUS = new StrutsMessage("title.actor_status");
    public static final StrutsMessage TITLE_GRANT_PERMISSION = new StrutsMessage("title.grant_permission");

    public static final StrutsMessage SUBSTITUTION_ALWAYS = new StrutsMessage("substitution.always");
    public static final StrutsMessage LABEL_SUBSTITUTORS = new StrutsMessage("label.substitutors");
    public static final StrutsMessage LABEL_SUBSTITUTORS_CRITERIA = new StrutsMessage("label.substitutors_criteria");
    public static final StrutsMessage LABEL_SUBSTITUTORS_ENABLED = new StrutsMessage("label.substitutors_enabled");
    public static final StrutsMessage LABEL_SUBSTITUTION_CRITERIA_NAME = new StrutsMessage("label.substitution_criteria_name");
    public static final StrutsMessage LABEL_SUBSTITUTION_CRITERIA_TYPE = new StrutsMessage("label.substitution_criteria_type");
    public static final StrutsMessage LABEL_SUBSTITUTION_CRITERIA_CONF = new StrutsMessage("label.substitution_criteria_conf");
    public static final StrutsMessage TITLE_TERMINATOR_EDIT = new StrutsMessage("terminator.edit.title");
    public static final StrutsMessage TITLE_SUBSTITUTION_EDIT = new StrutsMessage("substitutioncriteria.edit.title");
    public static final StrutsMessage LABEL_SUBSTITUTION_SELECT = new StrutsMessage("substitution.select");
    public static final StrutsMessage LABEL_SUBSTITUTION_CRITERIA_USED_BY = new StrutsMessage("label.substitutioncriteria.usedby");
    public static final StrutsMessage LABEL_SWIMLANE_ORGFUNCTION = new StrutsMessage("label.swimlane_organization_function");

    public static final StrutsMessage DYNAMIC_GROUP_NAME = new StrutsMessage("dynamic_group.name");
    public static final StrutsMessage ESCALATION_GROUP_NAME = new StrutsMessage("escalation_group.name");

    public static final StrutsMessage TITLE_RELATIONS = new StrutsMessage("title.relations");
    public static final StrutsMessage LINK_CREATE_RELATION = new StrutsMessage("link.create_relation");
    public static final StrutsMessage LINK_CREATE_RELATION_PAIR = new StrutsMessage("link.create_relation_pair");
    public static final StrutsMessage LABEL_RELATION_FROM = new StrutsMessage("label.relation_pair.from");
    public static final StrutsMessage LABEL_RELATION_TO = new StrutsMessage("label.relation_pair.to");
    public static final StrutsMessage LABEL_RELATION_NAME = new StrutsMessage("label.relation.name");
    public static final StrutsMessage LABEL_RELATION_DESCRIPTION = new StrutsMessage("label.relation.description");
    public static final StrutsMessage TITLE_EXECUTOR_RIGHT_RELATIONS = new StrutsMessage("title.executor.right.relations");
    public static final StrutsMessage TITLE_EXECUTOR_LEFT_RELATIONS = new StrutsMessage("title.executor.left.relations");
    public static final StrutsMessage TITLE_RELATION_DETAILS = new StrutsMessage("title.relation.details");
    public static final StrutsMessage TITLE_CREATE_RELATION_PAIR = new StrutsMessage("title.create_relation_pair");
    public static final StrutsMessage TITLE_CREATE_ACTOR = new StrutsMessage("title.create_actor");
    public static final StrutsMessage TITLE_CREATE_GROUP = new StrutsMessage("title.create_group");

    public static final StrutsMessage LABEL_YOU_ARE_NOT_ENABLED_WITH_SUBSTITUTIONS = new StrutsMessage("label.you_are_not_active_with_substitutions");
    public static final StrutsMessage LABEL_YOU_ARE_NOT_ENABLED_WITHOUT_SUBSTITUTIONS = new StrutsMessage(
            "label.you_are_not_active_without_substitutions");
    public static final StrutsMessage SYNCHRONIZATION_COMPLETED = new StrutsMessage("executors.synchronization.completed");
}

==> runawfe-free-server-4.5.0.tar.gz: runawfe-free-server-4.5.0/wfe-web/src/main/java/ru/runa/af/web/MessagesExecutor.java <==
package ru.runa.af.web;

import ru.runa.common.web.StrutsMessage;

public final class MessagesExecutor {

    public static final StrutsMessage UNAUTHORIZED_EXECUTOR_NAME = new StrutsMessage("label.executor.unauthorized");

    public static final StrutsMessage TITLE_EXECUTORS = new StrutsMessage("title.executors");
    public static final StrutsMessage CREATE_ACTOR = new StrutsMessage("button.create_actor");
    public static final StrutsMessage CREATE_GROUP = new StrutsMessage("button.create_group");

    public static final StrutsMessage EXECUTOR_NAME = new StrutsMessage("label.executor_name");
    public static final StrutsMessage EXECUTOR_DESCRIPTION = new StrutsMessage("label.executor_description");
    public static final StrutsMessage ACTOR_FULL_NAME = new StrutsMessage("label.actor_fullname");
    public static final StrutsMessage ACTOR_CODE = new StrutsMessage("label.actor_code");
    public static final StrutsMessage ACTOR_IS_ACTIVE = new StrutsMessage("label.actor_is_active");
    public static final StrutsMessage ACTOR_EMAIL = new StrutsMessage("label.actor_email");
    public static final StrutsMessage ACTOR_PHONE = new StrutsMessage("label.actor_phone");
    public static final StrutsMessage ACTOR_TITLE = new StrutsMessage("label.actor_title");
    public static final StrutsMessage ACTOR_DEPARTMENT = new StrutsMessage("label.actor_department");
    public static final StrutsMessage GROUP_AD = new StrutsMessage("label.group_ad");

    public static final StrutsMessage TITLE_SUBSTITUTION_CRITERIA = new StrutsMessage("title.substitution_criteria");
    public static final StrutsMessage TITLE_ADD_EXECUTORS_TO_GROUP = new StrutsMessage("title.add_executors_to_group");
    public static final StrutsMessage TITLE_ADD_EXECUTOR_TO_GROUP = new StrutsMessage("title.add_executor_to_groups");
    public static final StrutsMessage TITLE_EXECUTOR_DETAILS = new StrutsMessage("title.executor_details");
    public static final StrutsMessage TITLE_EXECUTOR_GROUPS = new StrutsMessage("title.executor_groups");
    public static final StrutsMessage TITLE_GROUP_MEMBERS = new StrutsMessage("title.group_members");
    public static final StrutsMessage TITLE_ACTOR_PASSWORD = new StrutsMessage("title.actor_password");
    public static final StrutsMessage TITLE_ACTOR_STATUS = new StrutsMessage("title.actor_status");
    public static final StrutsMessage TITLE_GRANT_PERMISSION = new StrutsMessage("title.grant_permission");

    public static final StrutsMessage SUBSTITUTION_ALWAYS = new StrutsMessage("substitution.always");
    public static final StrutsMessage LABEL_SUBSTITUTORS = new StrutsMessage("label.substitutors");
    public static final StrutsMessage LABEL_SUBSTITUTORS_CRITERIA = new StrutsMessage("label.substitutors_criteria");
    public static final StrutsMessage LABEL_SUBSTITUTORS_ENABLED = new StrutsMessage("label.substitutors_enabled");
    public static final StrutsMessage LABEL_SUBSTITUTION_CRITERIA_NAME = new StrutsMessage("label.substitution_criteria_name");
    public static final StrutsMessage LABEL_SUBSTITUTION_CRITERIA_TYPE = new StrutsMessage("label.substitution_criteria_type");
    public static final StrutsMessage LABEL_SUBSTITUTION_CRITERIA_CONF = new StrutsMessage("label.substitution_criteria_conf");
    public static final StrutsMessage TITLE_TERMINATOR_EDIT = new StrutsMessage("terminator.edit.title");
    public static final StrutsMessage TITLE_SUBSTITUTION_EDIT = new StrutsMessage("substitutioncriteria.edit.title");
    public static final StrutsMessage LABEL_SELECT = new StrutsMessage("label.select");
    public static final StrutsMessage LABEL_SUBSTITUTION_CRITERIA_USED_BY = new StrutsMessage("label.substitutioncriteria.usedby");
    public static final StrutsMessage LABEL_SWIMLANE_ORGFUNCTION = new StrutsMessage("label.swimlane_organization_function");

    public static final StrutsMessage DYNAMIC_GROUP_NAME = new StrutsMessage("dynamic_group.name");
    public static final StrutsMessage ESCALATION_GROUP_NAME = new StrutsMessage("escalation_group.name");

    public static final StrutsMessage TITLE_RELATIONS = new StrutsMessage("title.relations");
    public static final StrutsMessage LINK_CREATE_RELATION = new StrutsMessage("link.create_relation");
    public static final StrutsMessage LINK_CREATE_RELATION_PAIR = new StrutsMessage("link.create_relation_pair");
    public static final StrutsMessage LABEL_RELATION_FROM = new StrutsMessage("label.relation_pair.from");
    public static final StrutsMessage LABEL_RELATION_TO = new StrutsMessage("label.relation_pair.to");
    public static final StrutsMessage LABEL_RELATION_NAME = new StrutsMessage("label.relation.name");
    public static final StrutsMessage LABEL_RELATION_DESCRIPTION = new StrutsMessage("label.relation.description");
    public static final StrutsMessage TITLE_EXECUTOR_RIGHT_RELATIONS = new StrutsMessage("title.executor.right.relations");
    public static final StrutsMessage TITLE_EXECUTOR_LEFT_RELATIONS = new StrutsMessage("title.executor.left.relations");
    public static final StrutsMessage TITLE_RELATION_DETAILS = new StrutsMessage("title.relation.details");
    public static final StrutsMessage TITLE_CREATE_RELATION_PAIR = new StrutsMessage("title.create_relation_pair");
    public static final StrutsMessage TITLE_CREATE_ACTOR = new StrutsMessage("title.create_actor");
    public static final StrutsMessage TITLE_CREATE_GROUP = new StrutsMessage("title.create_group");

    public static final StrutsMessage LABEL_YOU_ARE_NOT_ENABLED_WITH_SUBSTITUTIONS = new StrutsMessage("label.you_are_not_active_with_substitutions");
    public static final StrutsMessage LABEL_YOU_ARE_NOT_ENABLED_WITHOUT_SUBSTITUTIONS = new StrutsMessage(
            "label.you_are_not_active_without_substitutions");
    public static final StrutsMessage SYNCHRONIZATION_COMPLETED = new StrutsMessage("executors.synchronization.completed");
}
